"""
    Ory APIs

    Documentation for all public and administrative Ory APIs. Administrative APIs can only be accessed with a valid Personal Access Token. Public APIs are mostly used in browsers.   # noqa: E501

    The version of the OpenAPI document: v0.0.1-alpha.3
    Contact: support@ory.sh
    Generated by: https://openapi-generator.tech
"""


import unittest

import ory_client
from ory_client.api.default_api import DefaultApi  # noqa: E501


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_identity_admin(self):
        """Test case for create_identity_admin

        Create an Identity  # noqa: E501
        """
        pass

    def test_create_recovery_link_admin(self):
        """Test case for create_recovery_link_admin

        Create a Recovery Link  # noqa: E501
        """
        pass

    def test_delete_identity_admin(self):
        """Test case for delete_identity_admin

        Delete an Identity  # noqa: E501
        """
        pass

    def test_get_identity_admin(self):
        """Test case for get_identity_admin

        Get an Identity  # noqa: E501
        """
        pass

    def test_get_schema(self):
        """Test case for get_schema

        """
        pass

    def test_get_schema_admin(self):
        """Test case for get_schema_admin

        """
        pass

    def test_get_self_service_error(self):
        """Test case for get_self_service_error

        Get User-Facing Self-Service Errors  # noqa: E501
        """
        pass

    def test_get_self_service_error_admin(self):
        """Test case for get_self_service_error_admin

        Get User-Facing Self-Service Errors  # noqa: E501
        """
        pass

    def test_get_self_service_login_flow(self):
        """Test case for get_self_service_login_flow

        Get Login Flow  # noqa: E501
        """
        pass

    def test_get_self_service_login_flow_admin(self):
        """Test case for get_self_service_login_flow_admin

        Get Login Flow  # noqa: E501
        """
        pass

    def test_get_self_service_recovery_flow(self):
        """Test case for get_self_service_recovery_flow

        Get information about a recovery flow  # noqa: E501
        """
        pass

    def test_get_self_service_recovery_flow_admin(self):
        """Test case for get_self_service_recovery_flow_admin

        Get information about a recovery flow  # noqa: E501
        """
        pass

    def test_get_self_service_registration_flow(self):
        """Test case for get_self_service_registration_flow

        Get Registration Flow  # noqa: E501
        """
        pass

    def test_get_self_service_registration_flow_admin(self):
        """Test case for get_self_service_registration_flow_admin

        Get Registration Flow  # noqa: E501
        """
        pass

    def test_get_self_service_settings_flow(self):
        """Test case for get_self_service_settings_flow

        Get Settings Flow  # noqa: E501
        """
        pass

    def test_get_self_service_settings_flow_admin(self):
        """Test case for get_self_service_settings_flow_admin

        Get Settings Flow  # noqa: E501
        """
        pass

    def test_get_self_service_verification_flow(self):
        """Test case for get_self_service_verification_flow

        Get Verification Flow  # noqa: E501
        """
        pass

    def test_get_self_service_verification_flow_admin(self):
        """Test case for get_self_service_verification_flow_admin

        Get Verification Flow  # noqa: E501
        """
        pass

    def test_get_version_admin(self):
        """Test case for get_version_admin

        Return Running Software Version.  # noqa: E501
        """
        pass

    def test_initialize_self_service_browser_logout_flow(self):
        """Test case for initialize_self_service_browser_logout_flow

        Initialize Browser-Based Logout User Flow  # noqa: E501
        """
        pass

    def test_initialize_self_service_login_for_browsers(self):
        """Test case for initialize_self_service_login_for_browsers

        Initialize Login Flow for browsers  # noqa: E501
        """
        pass

    def test_initialize_self_service_login_for_native_apps(self):
        """Test case for initialize_self_service_login_for_native_apps

        Initialize Login Flow for Native Apps and API clients  # noqa: E501
        """
        pass

    def test_initialize_self_service_recovery_for_browsers(self):
        """Test case for initialize_self_service_recovery_for_browsers

        Initialize Recovery Flow for Browser Clients  # noqa: E501
        """
        pass

    def test_initialize_self_service_recovery_for_native_apps(self):
        """Test case for initialize_self_service_recovery_for_native_apps

        Initialize Recovery Flow for Native Apps and API clients  # noqa: E501
        """
        pass

    def test_initialize_self_service_registration_for_browsers(self):
        """Test case for initialize_self_service_registration_for_browsers

        Initialize Registration Flow for browsers  # noqa: E501
        """
        pass

    def test_initialize_self_service_registration_for_native_apps(self):
        """Test case for initialize_self_service_registration_for_native_apps

        Initialize Registration Flow for Native Apps and API clients  # noqa: E501
        """
        pass

    def test_initialize_self_service_settings_for_browsers(self):
        """Test case for initialize_self_service_settings_for_browsers

        Initialize Settings Flow for Browsers  # noqa: E501
        """
        pass

    def test_initialize_self_service_settings_for_native_apps(self):
        """Test case for initialize_self_service_settings_for_native_apps

        Initialize Settings Flow for Native Apps and API clients  # noqa: E501
        """
        pass

    def test_initialize_self_service_verification_for_browsers(self):
        """Test case for initialize_self_service_verification_for_browsers

        Initialize Verification Flow for Browser Clients  # noqa: E501
        """
        pass

    def test_initialize_self_service_verification_for_native_apps(self):
        """Test case for initialize_self_service_verification_for_native_apps

        Initialize Verification Flow for Native Apps and API clients  # noqa: E501
        """
        pass

    def test_is_alive_admin(self):
        """Test case for is_alive_admin

        Check HTTP Server Status  # noqa: E501
        """
        pass

    def test_is_ready_admin(self):
        """Test case for is_ready_admin

        Check HTTP Server and Database Status  # noqa: E501
        """
        pass

    def test_list_identities_admin(self):
        """Test case for list_identities_admin

        List Identities  # noqa: E501
        """
        pass

    def test_prometheus_admin(self):
        """Test case for prometheus_admin

        Get snapshot metrics from the Hydra service. If you're using k8s, you can then add annotations to your deployment like so:  # noqa: E501
        """
        pass

    def test_revoke_session(self):
        """Test case for revoke_session

        Initialize Logout Flow for API Clients - Revoke a Session  # noqa: E501
        """
        pass

    def test_submit_self_service_login_flow(self):
        """Test case for submit_self_service_login_flow

        Submit a Login Flow  # noqa: E501
        """
        pass

    def test_submit_self_service_recovery_flow(self):
        """Test case for submit_self_service_recovery_flow

        Complete Recovery Flow  # noqa: E501
        """
        pass

    def test_submit_self_service_recovery_flow_with_link_method(self):
        """Test case for submit_self_service_recovery_flow_with_link_method

        Complete Recovery Flow with Link Method  # noqa: E501
        """
        pass

    def test_submit_self_service_registration_flow(self):
        """Test case for submit_self_service_registration_flow

        Submit a Registration Flow  # noqa: E501
        """
        pass

    def test_submit_self_service_settings_flow(self):
        """Test case for submit_self_service_settings_flow

        Complete Settings Flow  # noqa: E501
        """
        pass

    def test_submit_self_service_verification_flow(self):
        """Test case for submit_self_service_verification_flow

        Complete Verification Flow  # noqa: E501
        """
        pass

    def test_to_session(self):
        """Test case for to_session

        Check Who the Current HTTP Session Belongs To  # noqa: E501
        """
        pass

    def test_update_identity_admin(self):
        """Test case for update_identity_admin

        Update an Identity  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from ory_client.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from ory_client.model.authenticate_ok_body import AuthenticateOKBody
from ory_client.model.container_change_response_item import ContainerChangeResponseItem
from ory_client.model.container_create_created_body import ContainerCreateCreatedBody
from ory_client.model.container_top_ok_body import ContainerTopOKBody
from ory_client.model.container_update_ok_body import ContainerUpdateOKBody
from ory_client.model.container_wait_ok_body import ContainerWaitOKBody
from ory_client.model.container_wait_ok_body_error import ContainerWaitOKBodyError
from ory_client.model.create_identity import CreateIdentity
from ory_client.model.create_recovery_link import CreateRecoveryLink
from ory_client.model.error_response import ErrorResponse
from ory_client.model.generic_error import GenericError
from ory_client.model.graph_driver_data import GraphDriverData
from ory_client.model.health_not_ready_status import HealthNotReadyStatus
from ory_client.model.health_status import HealthStatus
from ory_client.model.id_response import IdResponse
from ory_client.model.identity import Identity
from ory_client.model.identity_credentials import IdentityCredentials
from ory_client.model.image_delete_response_item import ImageDeleteResponseItem
from ory_client.model.image_summary import ImageSummary
from ory_client.model.inline_response200 import InlineResponse200
from ory_client.model.inline_response2001 import InlineResponse2001
from ory_client.model.inline_response503 import InlineResponse503
from ory_client.model.json_error import JsonError
from ory_client.model.login_flow import LoginFlow
from ory_client.model.login_via_api_response import LoginViaApiResponse
from ory_client.model.meta import Meta
from ory_client.model.plugin import Plugin
from ory_client.model.plugin_config import PluginConfig
from ory_client.model.plugin_config_args import PluginConfigArgs
from ory_client.model.plugin_config_interface import PluginConfigInterface
from ory_client.model.plugin_config_linux import PluginConfigLinux
from ory_client.model.plugin_config_network import PluginConfigNetwork
from ory_client.model.plugin_config_rootfs import PluginConfigRootfs
from ory_client.model.plugin_config_user import PluginConfigUser
from ory_client.model.plugin_device import PluginDevice
from ory_client.model.plugin_env import PluginEnv
from ory_client.model.plugin_interface_type import PluginInterfaceType
from ory_client.model.plugin_mount import PluginMount
from ory_client.model.plugin_settings import PluginSettings
from ory_client.model.port import Port
from ory_client.model.recovery_address import RecoveryAddress
from ory_client.model.recovery_flow import RecoveryFlow
from ory_client.model.recovery_link import RecoveryLink
from ory_client.model.registration_flow import RegistrationFlow
from ory_client.model.registration_via_api_response import RegistrationViaApiResponse
from ory_client.model.revoke_session import RevokeSession
from ory_client.model.self_service_error_container import SelfServiceErrorContainer
from ory_client.model.service_update_response import ServiceUpdateResponse
from ory_client.model.session import Session
from ory_client.model.settings_flow import SettingsFlow
from ory_client.model.settings_profile_form_config import SettingsProfileFormConfig
from ory_client.model.settings_via_api_response import SettingsViaApiResponse
from ory_client.model.submit_self_service_browser_settings_oidc_flow_payload import SubmitSelfServiceBrowserSettingsOIDCFlowPayload
from ory_client.model.submit_self_service_login_flow import SubmitSelfServiceLoginFlow
from ory_client.model.submit_self_service_login_flow_with_password_method import SubmitSelfServiceLoginFlowWithPasswordMethod
from ory_client.model.submit_self_service_recovery_flow_with_link_method import SubmitSelfServiceRecoveryFlowWithLinkMethod
from ory_client.model.submit_self_service_registration_flow import SubmitSelfServiceRegistrationFlow
from ory_client.model.submit_self_service_registration_flow_with_password_method import SubmitSelfServiceRegistrationFlowWithPasswordMethod
from ory_client.model.submit_self_service_settings_flow import SubmitSelfServiceSettingsFlow
from ory_client.model.submit_self_service_settings_flow_with_password_method import SubmitSelfServiceSettingsFlowWithPasswordMethod
from ory_client.model.submit_self_service_settings_flow_with_profile_method import SubmitSelfServiceSettingsFlowWithProfileMethod
from ory_client.model.submit_self_service_verification_flow_with_link_method import SubmitSelfServiceVerificationFlowWithLinkMethod
from ory_client.model.ui_container import UiContainer
from ory_client.model.ui_node import UiNode
from ory_client.model.ui_node_anchor_attributes import UiNodeAnchorAttributes
from ory_client.model.ui_node_attributes import UiNodeAttributes
from ory_client.model.ui_node_image_attributes import UiNodeImageAttributes
from ory_client.model.ui_node_input_attributes import UiNodeInputAttributes
from ory_client.model.ui_node_text_attributes import UiNodeTextAttributes
from ory_client.model.ui_nodes import UiNodes
from ory_client.model.ui_text import UiText
from ory_client.model.ui_texts import UiTexts
from ory_client.model.update_identity import UpdateIdentity
from ory_client.model.verifiable_identity_address import VerifiableIdentityAddress
from ory_client.model.verification_flow import VerificationFlow
from ory_client.model.version import Version
from ory_client.model.volume import Volume
from ory_client.model.volume_usage_data import VolumeUsageData
